#!/bin/sh
#
#  Component: archive
#
#  Description:
#
#  Check that the mounted archive drive is how full. If it reached the warning limit
#  and there is not an empty mount point then send a DrWatson message about that with 
#  WARNING level.
#  If the level reached the change limit and there is still not an empty mount point
#  it will send a DrWatson message with ERROR level. 
#  If there is an empty mount point and it is mounted it changes the actual MountPoint
#  else send a DrWatson message.
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#
#

. $HOME/etc/setenv.sh

[ ! -f $ARCHIVE_VAR/archive.cfg ] && exit 0

WarningLimit=60
ChangeLimit=85
EmptyMountPoints=""
StopArchive="99"
USED_PERCENT=0

. $ARCHIVE_VAR/archive.cfg

[ "$Archive" != "yes" ] && exit 0

if [ ! -d "$ARCHIVE_DIR/$MountPoint/" ] ; then
      $DRWATSON_HOME/addmessage.sh -i archive.$MountPoint.full -t ERROR -l NONE "The archive disk is not mounted"
      exit 1
fi


USED_PERCENT=`df -P $ARCHIVE_DIR/$MountPoint/ | tail -n -1 | awk '{print $5}' | sed 's;%$;;'`


if [ $USED_PERCENT -ge $StopArchive ] ; then
	touch $ARCHIVE_VAR/archive.$MountPoint.StopArchive
fi

if [ $USED_PERCENT -ge  $ChangeLimit ] ; then  
	if [ -z "$EmptyMountPoints" ] ; then
		$DRWATSON_HOME/addmessage.sh -i archive.$MountPoint.full -t ERROR -l NONE "The archive disk reached the Change level and you do not have an empty mount point! You must buy a disk and change the archive.cfg."
	else
		nextMp=""
		remainMp=""
		for mp in $EmptyMountPoints ; do
			if [ -d "$ARCHIVE_DIR/$mp" ] && [ -z "$nextMp"] ; then
				nextMp="$mp"
			else
				if [ -z "$remainMp" ] ; then
					remainMp="$mp"
				else
					remainMp=$remainMp" "$mp
				fi
			fi
		done
		
		if [ -z "$nextMp" ] ; then
			$DRWATSON_HOME/addmessage.sh -i archive.$MountPoint.full -t ERROR -l NONE "The archive disk reached the Change level and you have empty mount point(s) but unreachable!"
		else
			grep -v -e EmptyMountPoints -e MountPoint $ARCHIVE_VAR/archive.cfg > $ARCHIVE_VAR/archive_temp.cfg 
			echo "MountPoint=\""$nextMp\" >> $ARCHIVE_VAR/archive_temp.cfg
			echo "EmptyMountPoints=\""$remainMp\" >> $ARCHIVE_VAR/archive_temp.cfg
			$DRWATSON_HOME/addmessage.sh -i archive.$MountPoint.full -t READY "New archive disk installed"
			mv $ARCHIVE_VAR/archive_temp.cfg $ARCHIVE_VAR/archive.cfg
		fi
	fi

elif [ $USED_PERCENT -ge $WarningLimit ] && [ -z "$EmptyMountPoints" ]; then
		$DRWATSON_HOME/addmessage.sh -i archive.$MountPoint.full -t WARNING -l TMP "The archive disk reached the warning level and you do not have an empty mount point! You should buy a disk and change the archive.cfg."
fi

