#!/bin/sh

. $HOME/etc/setenv.sh

#
# --- $1: Target directory name (STYIUID)
#     $2: Source and target file name for extracting (both are DICOM files)
#

SOUR_DIR=`$REPOSITORYHANDLER_HOME/bin/createDirectory $REPOSITORY_DATA_DICOM $1`
result=$?
if [ $result -ne 0 ] ; then
	echo "failed to create study directory"
	echo "createDirectory returned $result"
fi
SOUR=${SOUR_DIR}/$2
SOUR_OLD=${IMAGE_DATA}/$2
TARGDIR_C=`$REPOSITORYHANDLER_HOME/bin/createDirectory $REPOSITORY_CACHE $1`
result=$?
if [ $result -ne 0 ] ; then
	echo "failed to create cache directory"
	echo "createDirectory returned $result"
fi
TARGDIR_P=`$REPOSITORYHANDLER_HOME/bin/createDirectory $REPOSITORY_PROCESSED $1`
result=$?
if [ $result -ne 0 ] ; then
	echo "failed to create processed directory"
	echo "createDirectory returned $result"
fi
TARGFILE_C=${TARGDIR_C}/$2
TARGFILE_P=${TARGDIR_P}/$2
TMPDIR=${TMP}/extract.$$

LOGGER="/usr/bin/logger"
TAG="extract[$$]"

#
# --- Force locq. Remove shit if previous instance aborted abnormally
#
LOCQ=${TMP}/$2.locq
LOCQFILE=${TMP}/$2.locq.$$
. $CASES_HOME/locq.shi

#
# --- The semaphore is here. Create target if it hasn't been
#     created meanwhile. Place into temporary directory first
#

if [ ! -f "$TARGFILE_P" -o ! -f "${TARGFILE_P}_1.128x128t.raw" -o ! -f "${TARGFILE_P}.desc" -o ! -f "${TARGFILE_C}_1.raw" ]; then

  echo "`date`: extract[$$]: $1/$2"
  $LOGGER -p $LOG_FACILITY.info -t "$TAG" "$1/$2" 

  mkdir $TMPDIR
  rm -f $TMPDIR/*
  
# dicom images moved from IMAGE_DATA to REPOSITORY_DICOM_DATA/Study/
  if [ ! -f "${SOUR}" -a -f "${SOUR_OLD}" ] ; then
    mv ${SOUR_OLD} ${SOUR}
  fi
  
  $DCVIEWER_HOME/herelo ${SOUR} $TMPDIR/$2

# --- Move files to target. Make p2i conversion if necessary
#     (for pumping .raw, and for creating .sph)
  if [ 0 = $? ]; then
    P2i=""
    export P2i

    Byte=1
    cat $TMPDIR/$2.desc | while read RNum RClm RRow RInterl0 RDepth RShift; do
      if [ "byplane" = "$RInterl0" ]; then
        [ "16" = "$RDepth" ] && Byte=2
        mv $TMPDIR/${2}_$RNum.raw $TMPDIR/${2}_$RNum.pln
        $SPIHT_HOME/p2i -b$Byte $TMPDIR/${2}_$RNum.pln $TMPDIR/${2}_$RNum.raw
        rm $TMPDIR/${2}_$RNum.pln

        #P2i=true #doesn't work (even if exported)
        echo "P2i" >$TMPDIR/p2i.$$
      fi
    done

#QZ check : is $P2i visible outside of while ? NOT
    if [ -e $TMPDIR/p2i.$$ ]; then
      mv $TMPDIR/$2.desc $TMPDIR/$2.pln
      sed -e 's|byplane|bypixel|' $TMPDIR/$2.pln >$TMPDIR/$2.desc
      rm $TMPDIR/$2.pln
    fi

#    move the results 
#    ( *t.raw thumbnails, *.raw images, *.desc description, * processed )

    mv $TMPDIR/*.desc $TARGDIR_P
    mv $TMPDIR/*.raw $TARGDIR_C
    mv $TMPDIR/* $TARGDIR_P
    [ 0 = $? ] && rmdir $TMPDIR

    $CASES_HOME/cachelim.sh > /dev/null 2>&1

  fi

fi

rm $LOCQ $LOCQFILE 2>/dev/null
