var timeLines = new Array();
var timeLineMap = new Array();

function refreshTLs() {
	for ( var i = 0; i < timeLines.length; i++ ) {
		timeLines[ i ].render();
	}
}

function adjustTLSizes() {
	for ( var i = 0; i < timeLines.length; i++ ) {
		timeLines[ i ].adjustSize();
	}
}

function addResizeEvent( func ) {
	var oldresize = window.onresize;
	if ( typeof oldresize != 'function' ) {
		window.onresize = func;
	}
	else {
		window.onresize = function() {
			oldresize();
			func();
		};
	}
};

function getBoxHeight() {

	var $inspector = $( "<div>" ).css( 'display', 'none' ).addClass( "TLDivCommon" );
	$( "body" ).append( $inspector ); // add to DOM, in order to read the CSS
										// property
	try {
		return $inspector.height();
	}
	finally {
		$inspector.remove(); // and remove from DOM
	}
};

function Timeline( root ) {
	timeLines.push( this );
	timeLineMap[ root ] = this;
	addResizeEvent( adjustTLSizes );
	addLoadEvent( refreshTLs );
	this.root = root;
	this.container = document.getElementById( root );
	this.container.style.position = "relative";
	this.scrollDiv = document.createElement( 'div' );
	this.scrollDiv.style.position = 'absolute';
	this.scrollDiv.style.overflowY = "auto";
	this.container.appendChild( this.scrollDiv );
	this.rootElement = document.createElement( 'div' );
	this.rootElement.style.position = 'relative';
	this.scrollDiv.appendChild( this.rootElement );
	this.width = $( this.container ).width();
	$( this.scrollDiv ).width( this.width );

	// calculate boxHeight
	this.boxheight = getBoxHeight() + 6; // the inner size + 8 for top and
											// bottom
	this.groupSep = 10; // seperator extra space between study groups
	// border+padding
	// detect height/width from css rules

	this.n = 0;
	this.dirty = false;

	this.objects = new Array();

	this.sortByDate = function( a, b ) {
		if ( ( b.date - a.date ) == 0 ) {
			if ( b.isGroupLast ) {
				return -1;
			}
			if ( a.isGroupLast ) {
				return 1;
			}
			return 0;
		}
		return b.date - a.date;
	};

	this.setDivStyle = function( div ) {
		// div.style.height = ( this.boxheight - 8 ) + 'px';
		div.style.position = 'absolute';
		div.style.overflow = 'hidden';
		div.style.textOverflow = 'ellipsis';
		div.style.left = '20px';
	};

	this.setObjects = function( objs ) {
		this.objects = objs;
		this.dirty = true;
		this.render();
	};

	this.clearObjects = function() {
		while ( this.objects.pop() ) {
		}
		this.dirty = true;
	};

	this.clear = function() {
		while ( this.rootElement.hasChildNodes() ) {
			this.rootElement.removeChild( this.rootElement.firstChild );
		}
	};

	this.render = function() {
		this.clear();
		if ( this.dirty ) {
			// should be sorted by date descending -- actually sort??
			this.objects.sort( this.sortByDate );
			this.dirty = false;
		}

		this.n = this.objects.length;
		// element's height...
		var sepCount = 0;
		for ( var o = 0; o < this.objects.length; o++ ) {
			var obj = this.objects[ o ];

			// find, or create the div
			if ( obj.id ) {
				var div0 = document.getElementById( obj.id );

				if ( div0 != null ) {
					if ( div0.parentNode != this.root && div0.parentNode != null ) {
						throw ( "Timeline: Element '" + obj.id + "' has wrong parent" );
					}
					if ( obj.div != null && obj.div != div0 ) {
						throw ( "Timeline: stored div '" + obj.div + "' doesn't match" );
					}
					obj.div = div0;
				}
			}
			if ( obj.div == null ) {
				// we'll create the document;
				obj.div = document.createElement( 'div' );
				if ( obj.style != null ) {
					for ( var s in obj.style ) {
						obj.div.style[ s ] = obj.style[ s ];
					}
				}
				if ( obj.className != null ) {
					obj.div.className = obj.className;
				}
				this.setDivStyle( obj.div );
			}
			var top = o * this.boxheight + 1 + sepCount * this.groupSep;
			obj.div.style.top = top + 'px';

			if ( obj.isGroupLast ) {
				sepCount++;
			}

			if ( obj.stem == null ) {
				obj.stem = document.createElement( 'div' );
				obj.stem.style.position = 'absolute';
				obj.stem.style.width = '29px';
				obj.stem.style.height = '3px';
				obj.stem.style.left = '5px';
				obj.stem.style.borderTop = 'black 2px solid';
				obj.stem.title = obj.date.toDateString();
			}
			// add the stem
			obj.stem.style.top = top + Math.floor( this.boxheight / 2 ) + 'px';
			if ( obj.stem.parentNode != this.rootElement ) {
				this.rootElement.appendChild( obj.stem );
			}
			// append if needed
			if ( obj.div.parentNode != this.rootElement ) {
				this.rootElement.appendChild( obj.div );
			}
		}
		$( this.scrollDiv ).height( $( this.container ).height() );

		var minHeight = this.objects.length * (this.boxheight) + 2 + (sepCount - 1) * this.groupSep;
		if ( $( this.rootElement ).height() < minHeight ) {
			$( this.rootElement ).height( minHeight );
		}

		// one single thick line
		var tickDiv = document.createElement( 'div' );

		with ( tickDiv.style ) {
			top = '0px';
			position = 'absolute';
			margin = '0 0 0 0';
			padding = '0 0 0 0';
			height = "100%";
			border = 'none 0px ';
			borderBottom = 'black 1px solid';
			left = '4px';
			width = '8px';
			background = '#303030';
		}
		this.rootElement.appendChild( tickDiv );
	};

	this.adjustSize = function() {
		$( this.scrollDiv ).height( $( this.container ).height() );
	}
};
