<%--
 * Component: cases
 *
 * Description:
 *  Interface for saving reports used by the viewer and remote dotcom servers.
 *
 * Parameters (multipart):
 *
 *   study        Study Instance UID
 *   unlock       Unlock study after saving report: true (= default), false
 *
 *   res_sopiuid              SOP Instance UID of the results
 *   impression               Name of the file containing impression text
 *   impression_html          Name of the file containing HTML impression
 *   impression_checksum      Check sum of the impression
 *   int#_typeid              Interpretation typeid of the #. interpretation
 *   int#_sopiuid             SOP Instance UID of the #. interpretation
 *   int#_statid              Status ID of the #. interpretation
 *   int#_figure              Attached images and annotations of the #. interpretation
 *   int#_author              Author of the #. interpretation
 *   int#_tscriber            Transcriber of the #. interpretation
 *   int#_recdate             Recorded date of the #. interpretation
 *   int#_rectime             Recorded time of the #. interpretation
 *   int#_override_recorded   Override existing recdate/rectime values in the #. interpretation
 *   int#_dictuid             SOP Instance UID of dictation of the #. interpretation
 *   int#_text                Name of the file containing interpretation text of the #. interpretation
 *   int#_text_html           Name of the file containing HTML interpretation text of the #. interpretation
 *   int#_text_checksum       Check sum of the text of #. interpretation
 *   int#_sound               Name of the file containing dictation sound of the #. interpretation
 *   int#_note                Name of the file containing Radiologist's note for the #. interpretation
 *   int#_normality           Normality status (is there any abnormality reported in the interpretation)
 *   int#_birads              BI-RADS code for Breast Imaging/Mammography reports
 *
 *  # is a serial number started with 0
 *
 * Last Updated     : $Author$
 * Update Date Time : $Date$
 * RCS File Name    : $RCSfile$
 * RCS Revision     : $Revision$
 * Locked by        : $Locker$
 * Symbolic name    : $Name$
 * State            : $State$
 *
--%><%@page import="com.erad.pacs.modules.gwt.exception.usermanager.IMRedirectedException"%>
<%@page import="com.erad.pacs.modules.gwt.session.right.PacsRight"%>
<%@page import="com.erad.pacs.modules.gwt.descriptors.usermanager.SessionInfo"%>
<%@page import="com.erad.pacs.connector.Connector"%>
<%@page import="com.erad.pacs.services.usermanager.client.Session"%>
<%@page import="com.erad.pacs.services.usermanager.client.RequestConsts"%>
<%@
	page import="imagemed.util.*,imagemed.imsession.*,imagemed.jsputil.*,java.io.*, java.sql.*,
			java.util.*, imagemed.http.tabs.*, imagemed.layout.macro.input.TextInputMacro"

%><%@
	page errorPage ="../main/exceptionHandler.jsp"

%><%!
	// The smallest version of the viewer with Addendum support
	// Do not enable edit reports with addendum with previous versions
	static final String supportedViewer="PracticeBuilder 1-2-3 Version 3.6 (Build 01.0)";

	static boolean checkUserAgent(HttpServletRequest req, HttpServletResponse resp) throws IOException {
		String useragent = req.getHeader("user-agent");
		if (useragent == null || ! useragent.startsWith("PracticeBuilder 1-2-3 Version"))
			return true;

		if (useragent.compareTo(supportedViewer) < 0) {
			resp.sendError(500, "Invalid viewer version. Viewer is not supported");
			return false;
		}

		return true;
	}

%><%

	if (!TabBean.hasLicense( TabBean.LICENSE_REPORT ) ) {
		%>FAILED<%
		return;
	}

	Syslog logger = new Syslog("putrep",0,IMEnvBase.getEnv("LOG_FACILITY"));
	Session sess = null;
	try {
		sess = DotcomToolbox.checkAndCreateSession( request, response, new SessionInfo( request.getParameter( RequestConsts.QUERYSTRING_SESSION_ID_NAME ), null, null, null, null, null, null, null) );
	}
	catch ( IMRedirectedException re ) {
		return;
	}
	catch (Throwable th) {
		logger.syslog(Syslog.LOG_DEBUG, "Exception when checking for session " + Helper.throwable2String(th));

		%>FAILED<%return;
	}
	if ( !checkUserAgent( request, response ) )
		return;

	JspSession jspSess = new JspSession(sess, request, response, out );
	
	MultipartRequest mp = new MultipartRequest( request, IMEnvBase.getEnv("TMP") );

//	Helper.writeTextFile( IMEnvBase.getEnv( "TMP" ) + "/putrep.dump." + is._sid, Helper.request2String(mp));

	String parStudy   = mp.getParameter("study");
	String parProposedStudy = mp.getParameter("proposedstudy"); // saving reports for orders
	// NOTE: prposedstudy can only be received from the WEB based report editor (reportview.jsp)
	// We will check for Proposed Study Instance UID for orders in the SQL database for reports
	// received from the viewer
	String parUnlock  = mp.getParameter("unlock"); // default true
	String parStatus  = mp.getParameter("status");

	boolean bUnlock = ! "false".equals(parUnlock);

	logger.syslog(Syslog.LOG_DEBUG,parStudy + " " + sess.getSessionId() );

/*
	// Uncomment this section to log parameters in debug log

	for (Enumeration e = mp.getParameterNames(); e.hasMoreElements();) {
		String parName = (String) e.nextElement();
		String parVals[] = mp.getParameterValues(parName);
		if (parVals == null)
			continue;
		for (int i = 0 ; i < parVals.length ; i++)
			logger.syslog(Syslog.LOG_DEBUG,"PARAM " + parName + " = [" + parVals[i] + "]");
	}

	for (Enumeration e = request.getHeaderNames(); e.hasMoreElements();) {
		String headerName = (String) e.nextElement();
		String headerValue = request.getHeader(headerName);
		logger.syslog(Syslog.LOG_DEBUG,"HEADER " + headerName + " = [" + headerValue + "]");
	}*/


	logger.syslog( Syslog.LOG_DEBUG, "Session: " + sess.getSessionId() + "/" + sess.getUser().getUserId() + "/" + sess.getUser().getPrimaryGroup().getId() + "/" + sess.getRights().getStringRepresentation() );

	if (null == parStudy) {
		logger.syslog(Syslog.LOG_DEBUG,"Study is null");
%>FAILED<%return;
	}

	// Translate Link Study UID to Source Study UID 
	String sourceStudy = StudyToolbox.getSourceStudyDB( parStudy );
	
	if ( !parStudy.equals( sourceStudy ) ) {
		logger.syslog(Syslog.LOG_DEBUG, "Source Study: " + sourceStudy );
		parStudy = sourceStudy;
	}
	Properties sessionVariables = new Properties();
	sessionVariables.setProperty( "sourceStudy", sourceStudy );
	
	if ( !sess.getRights().hasAnyOf( PacsRight.Report, PacsRight.Transcribe ) ) {
		logger.syslog(Syslog.LOG_DEBUG,"No Rights");
		response.setHeader("IMAuthentication","norights");%>FAILED<%
		return;
	}

	
	// redirect is not possible, because viewer (wininet) kaes get from the post - and no MultipartRequest

	// Read ProposedStudy UID for saving reports for orders 
	if (parProposedStudy == null) {
		try ( ResultSet rs = IMEnv.getDB().prepareStatement(
				"select PSTYIUID from " + IMEnvBase.getEnv( "STUDYTBL" ) + " where STYIUID='" + parStudy + "'"
				).executeQuery() ) {
			if (rs.next()) {
				parProposedStudy = rs.getString("PSTYIUID");
				if (parProposedStudy != null && !"".equals(parProposedStudy)) {
					// Will be used in createPrpFromParams and will be passed to Report.java, but
					// will not be passed to child/parent server when request to be proxied
					if (sessionVariables == null)
						sessionVariables = new Properties();
					sessionVariables.setProperty("proposedStudy", parProposedStudy);
				}
			}
		}
		catch (SQLException sqlEx) {
			logger.syslog(Syslog.LOG_DEBUG, "Exception when checking for Proposed Study UID " + Helper.throwable2String(sqlEx));
%>FAILED<%
			return;
		}
	}

	// Check and add study fingerprint
	String fingerprint = mp.getParameter( "cFingerprint" );
	if ( fingerprint == null ) {
		String strViewSessionID = request.getHeader( "viewsessionid" );
		if ( strViewSessionID != null ) {
			try {
				fingerprint = VIDManager.getStudyFingerPrintStringFromVID( strViewSessionID, parStudy, false );
			}
			catch ( FileNotFoundException fnfeEx ) {
				// It's normal when saving reports for completed orders in a CWL environment
				if ( parProposedStudy == null ) {
					// But may be a real issue for regular studies: re-throw exception in such cases
					throw fnfeEx;
				}
			}
			if ( fingerprint != null ) {
				logger.syslog( Syslog.LOG_DEBUG, "Setting cFingerprint for " + parStudy ); 
				mp.addParam( "cFingerprint", fingerprint, MultipartRequest.MP_STRING_PARAM );
			}
		}
	}
	
	logger.syslog(Syslog.LOG_DEBUG,"before checkAndProxy " + parStudy + "/" + parProposedStudy);
	if ( ProxyToolbox.checkAndProxyReport( jspSess, parStudy, parProposedStudy, mp) ) {
		logger.syslog(Syslog.LOG_DEBUG,"checkAndProxy is true");

		return;
	}

	Properties prpReport = ReportToolbox.createPrpFromParams( sess, mp, request, sessionVariables );
	//Properties rspHeaders = new Properties();

	String result = Report.putReport(sess, prpReport, bUnlock, IMLock.getLockIDFromRequest( sess, request, parStudy ));

	if ("OK".equals(result)) {
		int numInt = 0;
		try {
			numInt = Integer.parseInt(prpReport.getProperty("NUM_OF_INTERPRETATIONS"));
		} catch (Throwable th) {
		}

		for (int i = 0; i < numInt; i++) {
			String sopiuid = prpReport.getProperty("INT" + i + "_SOPIUID");
			if (sopiuid != null)
				out.println("int" + i + "_sopiuid=" + sopiuid);
			String dictuid = prpReport.getProperty("INT" + i + "_SOUND_SOPIUID");
			if (dictuid != null)
				out.println("int" + i + "_dictuid=" + dictuid);
		}
%>OK<%
		if (true)
			return;
	}
	else {
		//for (Enumeration<?> e = rspHeaders.propertyNames() ; e.hasMoreElements() ; ) {
		//	String name = (String) e.nextElement();
		//	response.setHeader(name,rspHeaders.getProperty(name));
		//}
%>FAILED<%
		return;
	}

%>
