#!/bin/sh
#
# Purpose:
#   Nukes order recursively in the dotcom.
#
# Synopsis:
#   nukestudy.sh [-c] <order instance uid> [<except IP>]
#
# Arguments:
#    [-c]               : indicates the order is being nuked because completed (corrected to a study) 
#    order instance uid : Study Instance UID of the order to be nuked
#    except device      : ID of the device the nuke request received from
#
# Description:
#
# A flag file will be create in $TMP to avoid registering/sending DICOM
# objects for the order nuked. The name of the flag file is
# nuked.<study instance uid>
#
# Note:
#   nukestudy.sh will use setstudy.prp to be the nuke spread in the dotcom.
#
# ENDDOC
#
#  Last Modified by   : $Author$
#  Last modificied at : $Date$
#  RCS File Name      : $RCSfile$
#  RCS Revision       : $Revision$
#  Locked by          : $Locker$
#  Symbolic name      : $Name$
#  State              : $State$
#

. $HOME/etc/setenv.sh

isCompleted=""
if [ "$1" = "-c" ] ; then
	isCompleted="-c"
	shift
fi

study=$1
exceptDevice=$2


if [ -z "$study" ] ; then
	echo "Missing parameter"
	echo "usage:"
	echo "   obsolete.sh <study>"
	exit 1
fi


[ -f "$CONF/taskd.rc" ] && . $CONF/taskd.rc

params="$isCompleted -s \"$study\""
[ -n "$exceptDevice" ] && params="$params -H \"$exceptDevice\""
[ -n "$LOG_USER" ] && params="$params -u \"$LOG_USER\""


# echo "0 ${CASES_HOME#$HOME/component/}.NukeStudy $params" 
$TASKD_HOME/runjavacmd -c "0 ${CASES_HOME#$HOME/component/}.NukeStudy $params" -p $JAVA_SERVER_PORT

exit $?

