#!/bin/sh
#
# Component: cases
#
#  OBSOLETE: use cases.ObjectForward instead
#
# Description:
#  Forwards DICOM object to remote DICOM device.
#
# objfwd.sh will check if the target device is a child or parent server,
# and will determine if retrieved flag should be set on remote dotcom device.
#
# If target device is a child server, and the target server is not the
# OwnerDevice and not in the StagedDevices list, then it will be put into the
# StagedDevices list.
#
# USAGE: see usage_()
#
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh


# if objfwd.sh is called directly:
# run as a task instead
if [ `basename $0` = "objfwd.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi

LOGGER="/usr/bin/logger"
TAG="objfwd[$$]"


# Parameters
INPUT_PARAMS=""


ERRMSG=""

while getopts 'H:s:o:u:i:m:C:t:r:' OPT; do
	case $OPT in
	H) HostID="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -H \"$OPTARG\"" ;;
	s) Study="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -s \"$OPTARG\"" ;;
	o) File="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -o \"$OPTARG\"" ;;
	r) PbRFile="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -r \"$OPTARG\"" ;;
	u) LogUser="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -u \"$OPTARG\"" ;;
	i) DrWatsonID="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -i \"$OPTARG\"" ;;
	m) DrWatsonMessage="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -m \"$OPTARG\"" ;;
	C) CommitHost="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -C \"$OPTARG\"" ;;
	t) INPUT_PARAMS="$INPUT_PARAMS -t" ;;
	*) ERRMSG="Invalid_Parameter:$OPT" ;;
	esac
done

# override run_ method
run_()
{
	$LOGGER -p $LOG_FACILITY.debug -t "$TAG" "$TASKD_HOME/runjavacmd -n -c \"0 cases.ObjectForward $INPUT_PARAMS\""
	$TASKD_HOME/runjavacmd -c "0 cases.ObjectForward $INPUT_PARAMS" -p "$JAVA_SERVER_PORT"
	ERR=$?

	exit $ERR
}

# override cleanup_
cleanup_()
{
	$TASKD_HOME/runjavacmd -c "cleanup cases.ObjectForward $INPUT_PARAMS" -p "$JAVA_SERVER_PORT"
}


# override print_
print_()
{
	$TASKD_HOME/runjavacmd -c "print cases.ObjectForward $INPUT_PARAMS" -p "$JAVA_SERVER_PORT"
}


get_watson_message_()
{
	[ -z "$DrWatsonID" ] && DrWatsonID="fwd.$HostID.$Study"
	[ -z "$DrWatsonMessage" ] && DrWatsonMessage="Forwarding $Study to $HostID ($WATSON_ERRMSG)"

	if [ "$RUN_RESULT" -gt 124 ] ; then
		WATSON_MESSAGE_ID="$DrWatsonID.failed"
		WATSON_MESSAGE_TEXT="FAILED: $DrWatsonMessage"
		return
	fi

	if [ "$RUN_RESULT" -ne 0 -a "$RETRY_NUM" -gt 0 -a $(( $RETRY_NUM % 10)) -eq 0 ] ; then
		WATSON_MESSAGE_TEXT="ERROR: $DrWatsonMessage [Retry #$RETRY_NUM]"
		WATSON_MESSAGE_ID="$DrWatsonID.$RETRY_NUM"
	fi
} # get_watson_message_()
